Crate grow_sqlx

Crate grow_sqlx 

Structs

ExternalSqlValue

Enums

SqlValue
Represents a SQL value that can be used across different database drivers

Functions

escape_column_name
escape_table_name
execute_query
Execute a single SQL query with parameters (for seeder tracking)
execute_query_with_params
Execute a parameterized SQL query (for INSERT with values)
query_single_int
Execute a query that returns a single integer result (for counting)
query_single_text
Execute a query and return the first column of the first row as text
run_seeder
sql_value_from_external

Type Aliases

RenderedTable